@@ -5,7 +5,7 @@ use utf8;
 package Amon2::Setup::Flavor::Basic;
 use parent qw(Amon2::Setup::Flavor);
 
-our $VERSION = '6.04';
+our $VERSION = '6.05';
 
 sub run {
     my $self = shift;
@@ -40,7 +40,9 @@ sub run {
         'DBD::SQLite'                     => '1.33',
         'Test::WWW::Mechanize::PSGI'      => 0,
         'Router::Boom'                    => '0.06',
-        'HTTP::Session2'                  => '0.04',
+        'HTTP::Session2'                  => '1.03',
+        'Crypt::CBC'                      => '0',
+        'Crypt::Rijndael'                 => '0',
     });
 
     # static files
